#!/usr/bin/env python
# coding=utf-8
import os, sys
import glob # For filename search with wildcards
import copy

'''all_freshaxis.py: Shows, how the names of curve attributes can be changed
                     while the values of the attributes are kept the same.
SYNTAX:  @@all_,<frameset>[''],<arg2>[default?],<arg3>
        <frameset>: A file description (with wildcards) which specifies a set
                    of data files (extension: ".dat")
        <arg2>: not used in the demo
        <arg3>: not used in the demo
EXAMPLE: @@all_freshaxis,sy02_up*

Continue with ...'''


## Script procedures

def banner():
    # print the name of the running script
    myname = os.path.basename(sys.argv[0])
    self.poutput("Finished: {!r}".format(myname))
    pass
#END banner()

def doit():
    '''doit does the work'''
    #argument lister
    #for i, arg in enumerate(sys.argv[1:]):
    #    print("arg {}: {!r}".format(i+1, arg))

    ### Argument parsing
    argus = len( sys.argv ) - 1 # Number of provided arguments

    ## (1) The frame set to be worked on
    frameset = sys.argv[1]

    # If the user has given no extension, then append '.dat'
    test = frameset.split('.')
    if len(test) < 2:
        frameset = frameset+'.dat'

    # alphabetically sorted list of the specified files
    allfiles = sorted(glob.glob(frameset))
    if len(allfiles) < 1:
        return 'No files matching "%s"'%frameset
    ### End Argument parsing

    # Make a local operand which does not interfere
    # with the sascur operands
    thecurve = copy.deepcopy( self.ops[0] )
    ### Start doing the work
    for i, thefile in enumerate(allfiles):
        err = thecurve.readascii( thefile )
        if err:
            return err
        # rename axes-related attributes: abscissa to axis1; unitabs to units1 etc.
        source = ( 'abscissa', 'ordinate', 'unitabs', 'unitord' )
        dest   = ( 'axis1', 'axis2', 'units1', 'units2' )
        for i, key in enumerate( source ):
            val = thecurve.attribute( key )
            if val is not None:
                thecurve.attribute( dest[i], val )
                # thecurve.attribute( key, 'delete' )
        err = thecurve.writeascii( thefile, True ) # overwrite!
        if err:
            return err
        self.poutput('Units freshed: %s'%thefile)

#END doit()

# END script procedures

# Main:
err = doit()
if err:
    self.poutput( err, traceback_war=False )
    # No signaling of error to the caller
banner()
