#!/usr/bin/env python
# coding=utf-8
import os, sys
import glob # For filename search with wildcards
import copy # For true copies of variables
from scipy.interpolate import UnivariateSpline # Smooth curves by spline

'''setdespike.py: Postprocessing of a WAXS set to find and to remove spikes
                  in the rayonix detector
   setdespike.py and setdespike2.py have different despiking parameters.
SYNTAX: @@setdespike,<setname>,<truncate>
EXAMPLE: @@setdespike,bwy61_*,10.5
    <setname>:  The group of files which makes up the experimental run.
    <truncate>: an x-value at which the curve shall be truncated before
                processing
RESULT:
    The script generates new curve files named d<setfile>.dat
'''

## Script procedures

def banner():
    # print the name of the running script
    myname = os.path.basename(sys.argv[0])
    self.poutput("Finished: {!r}".format(myname))
    pass
#END banner()

def datfilesfound( test ):
    # True, if there are files matching the pattern
    missingext = len(test.split('.')) == 1
    if missingext:
        # No dot which indicates a file extension
        # Append default extension for data files
        testx = test+'.dat'
    else:
        testx = test
    listoffiles = glob.glob( testx )
    return len(listoffiles) > 0
#END datfilesfound()

def despike():
    '''despike does the work'''
    #argument lister
    #for i, arg in enumerate(sys.argv[1:]):
    #    print("arg {}: {!r}".format(i+1, arg))

    # Argument parsing of the first argument is postponed, because it
    # may involve the deletion of old files which shall only be done
    # just before the work starts.

    # Despiking parameters NOTICE They could be made arguments of this script
    threshold = 1.00 # similarity threshold (here: 100%) -- for the bad spikes in WAXD
    minwidth = 5 # Scratches narrower as minwidth are tolerable.
    fringe = 100 # For the significant scratches "fringe" neighbors (both to
                # right AND left) are considered affected and replaced

    ### Argument parsing
    argus = len(sys.argv) - 1
    if argus < 1:
        return "Script needs at least 1 argument"

    ## (1) The source set
    sources = sys.argv[1]
    # If the user has given no extension, then append '.dat'
    if sources.find('.') < 1:
        sources = sources+'.dat'
        pass
    if not datfilesfound( sources ):
        return 'There are no files matching "%s"'%sources

    ## (2) truncate
    if argus > 1:
        truncs = sys.argv[2]
        try:
            truncpos = float(truncs)
        except:
            return 'Error converting <truncpos> "%s" to float'%truncs
    else:
        truncpos = 0.0

    act = self.ops[0]
    setfiles = sorted(glob.glob(sources))
    for i, thefile in enumerate(setfiles):
        err = act.readascii( thefile )
        if err != '':
            return 'Error reading file "%s"'%thefile
        if truncpos > 0.0:
            act.delinterval(truncpos,None)
        if act.n < 10:
            return 'Curve "%s" is too short'%thefile
        if i > 0:
            mask = act.similarto( ref, threshold, fringe, minextend )
            act.bridgeit( mask )
        ref = copy.deepcopy( act )
        outfile = 'd'+thefile
        err = act.writeascii( outfile, True )

    self.poutput('New frameset "d%s" created by despiking of "%s"'%(sources,sources))
    return ''
#END despike()

# END script procedures

# Main:
err = despike()
if err != '':
    self.perror( err, traceback_war=False)
    # No special treatment in case of error
banner()



